/*
 * Copyright (c) 2013 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import bb.cascades 1.3
import bb.system 1.2

NavigationPane {
    id: nav
    attachedObjects: [
        ComponentDefinition {
            id: menu
        },
        Invocation {
            id: invoke
            query {
                invokeTargetId: "sys.appworld"
                uri: "http://appworld.blackberry.com/webstore/content/59935143"
            }
        },
        RenderFence {
            onReached: {
                timeSpentScrollView.requestFocus()
            }
        }
    ]
    Menu.definition: MenuDefinition {
        // Add a Help action        
        helpAction: HelpActionItem {
            onTriggered: {
                // Set the correct file source on the ComponentDefinition, create the Page, and set its title.
                menu.source = "help.qml";
                var page = menu.createObject();
                
                // Push the new Page.
                Application.menuEnabled = false;
                nav.push(page);
            }
        }
        
        // Add a Settings action
        settingsAction: SettingsActionItem {
            onTriggered: {
                menu.source = "settings.qml";
                var page = menu.createObject();
                
                // Push the new Page.
                Application.menuEnabled = false;
                nav.push(page);
            }
        }
        
        actions: [
/*            ActionItem {
                title: qsTr("Rate Volt") + Retranslate.onLanguageChanged
                ActionBar.placement: ActionBarPlacement.OnBar
                imageSource: "asset:///images/bb_world_white.png"
                onTriggered: invoke.trigger("bb.action.OPEN")
            }, */
            ActionItem {
                title: qsTr("About") + Retranslate.onLanguageChanged
                ActionBar.placement: ActionBarPlacement.OnBar
                imageSource: "asset:///images/ic_info.png"
                onTriggered: {
                    menu.source = "about.qml";
                    var page = menu.createObject();
                    
                    // Push the new Page.
                    Application.menuEnabled = false;
                    nav.push(page);
                }
            }
        ]      
    
    } // end of MenuDefinition
    onPopTransitionEnded: {
        page.destroy();    
        Application.menuEnabled = true;
    }
    
    Page{
        id: mainPage

        property double numberOfDoubleTaps: 0
                
        Container {
            background: Color.create("#ff8fff01")            
            layout: DockLayout {}
            horizontalAlignment: HorizontalAlignment.Fill
            verticalAlignment: VerticalAlignment.Fill
            Container {
                id: voltPercentContainer
                layout: DockLayout {}
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
                Container {
                    id: percentViewContainer
                    visible: _app.getSettings("percentViewContainerVisible", true) // == "true" ? true : false
                    horizontalAlignment: HorizontalAlignment.Center
                    verticalAlignment: VerticalAlignment.Center                        
                    Container {
                        horizontalAlignment: HorizontalAlignment.Center
                        Label {
                            multiline: true
                            //                            textStyle.base: SystemDefaults.TextStyles.BigText
                            textStyle.textAlign: TextAlign.Center
                            text: _app.voltPercent + " %"
                            textStyle.fontSize: FontSize.PointValue
                            textStyle.fontSizeValue: 20.0
                        }            
                    }
                    TrustMeter {
                        trust: _app.trustMeter
                    }                    
                }
                Container {
                    id: timeSpentViewContainer
                    visible: !percentViewContainer.visible
                    layout: DockLayout {}
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Fill
                    ScrollView {
                        id: timeSpentScrollView
                        scrollRole: scrollView.visible ? ScrollRole.None : ScrollRole.Main
                        horizontalAlignment: HorizontalAlignment.Center
                        verticalAlignment: VerticalAlignment.Center 
                        TimeSpent {}                        
                    }
                }
            }
            ScrollView {
                id: scrollView
                visible: false
                scrollRole: visible ? ScrollRole.Main : ScrollRole.None
                onVisibleChanged: {
                    _udp.sendMessage("HIDDENVIEWISSHOWN_CHANGED$$" + visible.toString().toLowerCase())
                }
                Container {
                    horizontalAlignment: HorizontalAlignment.Fill
                    verticalAlignment: VerticalAlignment.Fill
                    Container {
                        horizontalAlignment: HorizontalAlignment.Center
                        topPadding: ui.sdu(3) // 30
                        CustomButton {
                            text: "Shut down headless"
                            onClicked: {
                                _app.shutDown()
                            }
                        }
                    }
                    Container {
                        id: m_rawData
                        objectName: "m_rawData"
                        topPadding: ui.sdu(3) // 30
                        bottomPadding: topPadding
                        rightPadding: topPadding
                        leftPadding: topPadding            
                        Container {
                            bottomPadding: ui.sdu(3) // 30
                            layout: StackLayout {
                                orientation: LayoutOrientation.LeftToRight
                            }
                            Label {
                                text: "Battery ID : " + _app.getSettings("currentBatteryId", "");
                            }                    
                        }
                        Container {
                            bottomPadding: ui.sdu(3) // 30
                            layout: StackLayout {
                                orientation: LayoutOrientation.LeftToRight
                            }
                            Label {
                                text: "Enter battery size :"
                            }
                            TextField {
                                text: _app.getSettings(_app.getSettings("currentBatteryId", "") + "/batterySize", "1800")
                                hintText: "ie: 3500"
                                inputMode: TextFieldInputMode.NumbersAndPunctuation
                                onTextChanging: {
                                    _app.saveSettings(_app.getSettings("currentBatteryId", "") + "/batterySize", text)
                                }
                            }
                        }
                        Container {
                            bottomPadding: ui.sdu(3) // 30
                            layout: StackLayout {
                                orientation: LayoutOrientation.LeftToRight
                            }
                            Label {
                                text: "Modify max consumed (not recommended):"
                                multiline: true
                            }
                            TextField {
                                property string maxConsumed: _app.getJsonValue("maxConsumed").toString()
                                id: maxConsumedTextField
                                text: maxConsumed == "false" ? "" : maxConsumed
                                hintText: "ie: 3123"
                                minWidth: ui.sdu(30) // 300
                                inputMode: TextFieldInputMode.NumbersAndPunctuation
                                onTextChanging: _udp.sendMessage("MAXCONSUMED_CHANGED$$" + text)
                            }
                        }
                        Container {
                            bottomPadding: ui.sdu(3) // 30
                            layout: StackLayout {
                                orientation: LayoutOrientation.LeftToRight
                            }
                            Label {
                                text: "Modify 1% value (not recommended):"
                                multiline: true
                            }
                            TextField {
                                property string consumedAt1Percent: _app.getJsonValue("consumedAt1Percent").toString()
                                id: consumedAt1PercentTextField
                                text: consumedAt1Percent == "false" ? "" : consumedAt1Percent
                                hintText: "ie: 2678"
                                minWidth: ui.sdu(30) // 300
                                inputMode: TextFieldInputMode.NumbersAndPunctuation
                                onTextChanging: _udp.sendMessage("CONSUMEDAT1PERCENT_CHANGED$$" + text)
                            }
                        }
                        Label {
                            horizontalAlignment: HorizontalAlignment.Center
                            multiline: true
                            text: _app.label1Text
                        }
                        Label {
                            horizontalAlignment: HorizontalAlignment.Center
                            multiline: true
                            text: _app.label2Text
                        }                    
                    } // end of rawData container
                } // end of main container
            } // end of ScrollView        
            
            gestureHandlers: [
                DoubleTapHandler {
                    onDoubleTapped: {
                        mainPage.numberOfDoubleTaps++
                        if (mainPage.numberOfDoubleTaps == 2) {
                            mainPage.numberOfDoubleTaps = 0
                            voltPercentContainer.visible = !voltPercentContainer.visible
                            scrollView.visible = !scrollView.visible                            
                        }
                    }
                },
                TapHandler {
                    onTapped: {
                        percentViewContainer.visible = timeSpentViewContainer.visible
                        timeSpentViewContainer.visible = !percentViewContainer.visible                                                
                        _app.saveSettings("percentViewContainerVisible", percentViewContainer.visible)
                    }
                }
            ]            
        }
        
        attachedObjects: [
            Tutorial {
                id: tutorial
            }
        ]
        
        onCreationCompleted: {
            // Lock device orientation to portrait on startup
            OrientationSupport.supportedDisplayOrientation = SupportedDisplayOrientation.DisplayPortrait;  
            
            //when the main.qml is created (app is launched) we check the bool property to see if the 
            //tutorial needs to run or not
            console.log("Settings: " + _app.getSettings("firstRun", "true"))
            if (_app.getSettings("firstRun", "true") == "true") 
                //So if the bool property isn't false, the tutorial sheet will automatically open
                tutorial.open()
            else 
                tutorial.destroy()
        }
    } // end of Page
}