import bb.cascades 1.3
import bb.system 1.2

Page {
    actions: [
        ActionItem {
            title: qsTr("Rate Volt") + Retranslate.onLanguageChanged
            ActionBar.placement: ActionBarPlacement.Signature
            imageSource: "asset:///images/bbw.png"
            onTriggered: invoke.trigger("bb.action.OPEN")
        }
    ]
    Container {
        background: Color.create("#ff8fff01")            
        ScrollView {
            Container {
                topPadding: ui.sdu(3) // 30
                bottomPadding: topPadding
                leftPadding: topPadding
                rightPadding: topPadding            
                Container {
                    LineDivider {}
                    Container {
                        Label {
                            horizontalAlignment: HorizontalAlignment.Center
                            text: qsTr("Full discharge cycle") + Retranslate.onLocaleOrLanguageChanged
                            textStyle.base: SystemDefaults.TextStyles.TitleText
                        }
                        Container {
                            layout: StackLayout {
                                orientation: LayoutOrientation.LeftToRight
                            }
                            Label {
                                verticalAlignment: VerticalAlignment.Center
                                multiline: true
                                text: qsTr("Have you performed a full discharge cycle at least once on this battery with Volt running (from 100% until it dies)?") + Retranslate.onLocaleOrLanguageChanged
                            }
                            ImageButton {
                                id: fullyDischargedImageButton
                                defaultImageSource: _app.getJsonValue("fullyDischargedOnce") ? "asset:///images/checked.png" : "asset:///images/notChecked.png" 
                                minWidth: ui.sdu(8) // 81
                                verticalAlignment: VerticalAlignment.Center
                                onClicked: {
                                    if (Number(_app.getJsonValue("maxConsumed")) > (Number(_app.getJsonValue("batterySize")) * 0.8)) {
                                        _app.setJsonValue("fullyDischargedOnce", !_app.getJsonValue("fullyDischargedOnce"))
                                        defaultImageSource = _app.getJsonValue("fullyDischargedOnce") ? "asset:///images/checked.png" : "asset:///images/notChecked.png"
                                    }
                                    else {
                                        if (_app.getJsonValue("fullyDischargedOnce")) {
                                            _app.setJsonValue("fullyDischargedOnce", !_app.getJsonValue("fullyDischargedOnce"))
                                            defaultImageSource = _app.getJsonValue("fullyDischargedOnce") ? "asset:///images/checked.png" : "asset:///images/notChecked.png"
                                        }
                                        else {
                                            systemDialog2.show()
                                        }
                                    }
                                }
                            }
                        }                        
                    }
                    LineDivider {}
                    Container {
                        horizontalAlignment: HorizontalAlignment.Fill
                        Label {
                            horizontalAlignment: HorizontalAlignment.Center
                            text: qsTr("First-run tutorial") + Retranslate.onLocaleOrLanguageChanged
                            textStyle.base: SystemDefaults.TextStyles.TitleText
                        }
                        CustomButton {
                            horizontalAlignment: HorizontalAlignment.Center
                            text: qsTr("Rerun tutorial") + Retranslate.onLocaleOrLanguageChanged
                            onClicked: {
                                tutorial.open()
                            }
                        }
                    }
                    LineDivider {}
                    Container {
                        visible: false
                        horizontalAlignment: HorizontalAlignment.Fill
                        Label {
                            horizontalAlignment: HorizontalAlignment.Center
                            text: qsTr("Reset all data") + Retranslate.onLocaleOrLanguageChanged
                            textStyle.base: SystemDefaults.TextStyles.TitleText
                        }
                        Button {
                            horizontalAlignment: HorizontalAlignment.Center
                            text: qsTr("Reset to default") + Retranslate.onLocaleOrLanguageChanged
                            onClicked: systemDialog.show()
                        }
                    }
                    Container {
                        visible: false
                        Header {
                            title: "View my stats"
                        }
                        Button {
                            text: "Show my stats"
                            onClicked: {
                                menu.source = "Stats.qml";
                                var page = menu.createObject();
                                
                                // Push the new Page.
                                nav.push(page);
                            }
                        }
                    }
                }
            }
        }
    }
    attachedObjects: [
        Tutorial {
            id: tutorial
        },
        SystemDialog {
            id: systemDialog
            title: qsTr("Delete all data?") + Retranslate.onLocaleOrLanguageChanged
            body: qsTr("Are you sure you want to reset to default? This will erase all data stored in Volt app.") + Retranslate.onLocaleOrLanguageChanged
            confirmButton.label: qsTr("Reset all") + Retranslate.onLocaleOrLanguageChanged
            confirmButton.enabled: true
            cancelButton.label: qsTr("Cancel") + Retranslate.onLocaleOrLanguageChanged
            cancelButton.enabled: true
            onFinished: {
                if (result == SystemUiResult.ConfirmButtonSelection) {
                    _app.clearData()
                }
            }
        },
        SystemDialog {
            id: systemDialog2
            title: qsTr("Are you sure?") + Retranslate.onLocaleOrLanguageChanged
            body: qsTr("Volt data doesn't look normal, your maximum mAh consumed during a single discharge is less than 80% of your battery size, which is odd. Are you sure you did a full discharge cycle without plugging the USB even once?") + Retranslate.onLocaleOrLanguageChanged
            confirmButton.label: qsTr("I'm sure") + Retranslate.onLocaleOrLanguageChanged
            confirmButton.enabled: true
            cancelButton.label: qsTr("Cancel") + Retranslate.onLocaleOrLanguageChanged
            cancelButton.enabled: true
            onFinished: {
                if (result == SystemUiResult.ConfirmButtonSelection) {
                    _app.setJsonValue("fullyDischargedOnce", !_app.getJsonValue("fullyDischargedOnce"))
                    fullyDischargedImageButton.defaultImageSource = _app.getJsonValue("fullyDischargedOnce") ? "asset:///images/checked.png" : "asset:///images/notChecked.png"
                }
            }
        }
    ]
}
